pub struct Parse { /* private fields */ }Expand description
The result of parsing a MASM source file into a lossless CST.
This type owns the green tree, retains the originating SourceFile, and exposes both
diagnostics and span helpers for later lowering.
Implementations
Sourceimpl Parse
impl Parse
Sourcepub fn syntax(&self) -> SyntaxNode
pub fn syntax(&self) -> SyntaxNode
Returns the raw rowan syntax tree rooted at SyntaxKind::SourceFile.
Sourcepub fn root(&self) -> SourceFile
pub fn root(&self) -> SourceFile
Returns the typed root node for this parse.
Sourcepub fn diagnostics(&self) -> &[Diagnostic]
pub fn diagnostics(&self) -> &[Diagnostic]
Returns any syntax diagnostics emitted while building the CST.
Sourcepub fn take_diagnostics(&mut self) -> Vec<Diagnostic>
pub fn take_diagnostics(&mut self) -> Vec<Diagnostic>
Removes and returns any syntax diagnostics emitted while building the CST.
Sourcepub fn source_file(&self) -> Arc<SourceFile>
pub fn source_file(&self) -> Arc<SourceFile>
Returns the source file used to produce this parse result.
Sourcepub fn source(&self) -> &SourceFile
pub fn source(&self) -> &SourceFile
Returns the source file used to produce this parse result by shared reference.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true when the parse emitted at least one syntax diagnostic.
Sourcepub fn span_for_ast_node<T>(&self, node: &T) -> SourceSpanwhere
T: AstNode<Language = MasmLanguage>,
pub fn span_for_ast_node<T>(&self, node: &T) -> SourceSpanwhere
T: AstNode<Language = MasmLanguage>,
Maps a rowan node back to a SourceSpan in the originating source file.
Sourcepub fn span_for_node(&self, node: &SyntaxNode) -> SourceSpan
pub fn span_for_node(&self, node: &SyntaxNode) -> SourceSpan
Maps a rowan node back to a SourceSpan in the originating source file.
Sourcepub fn span_for_token(&self, token: &SyntaxToken) -> SourceSpan
pub fn span_for_token(&self, token: &SyntaxToken) -> SourceSpan
Maps a rowan token back to a SourceSpan in the originating source file.
Sourcepub fn span_for_element(&self, element: &SyntaxElement) -> SourceSpan
pub fn span_for_element(&self, element: &SyntaxElement) -> SourceSpan
Maps a rowan element back to a SourceSpan in the originating source file.
Sourcepub fn span_for_range(&self, range: TextRange) -> SourceSpan
pub fn span_for_range(&self, range: TextRange) -> SourceSpan
Converts a rowan TextRange to a SourceSpan in the originating source file.