SyntaxKind

Enum SyntaxKind 

#[repr(u16)]
pub enum SyntaxKind {
Show 59 variants Tombstone = 0, Error = 1, SourceFile = 2, Doc = 3, Namespace = 4, ExternPackage = 5, Submodule = 6, Import = 7, ImportList = 8, ImportSpecifier = 9, Constant = 10, TypeDecl = 11, AdviceMap = 12, BeginBlock = 13, Procedure = 14, Attribute = 15, Visibility = 16, Signature = 17, Block = 18, IfOp = 19, WhileOp = 20, DoWhileOp = 21, RepeatOp = 22, Instruction = 23, Path = 24, Expr = 25, TypeBody = 26, Whitespace = 27, Newline = 28, Comment = 29, DocComment = 30, Ident = 31, SpecialIdent = 32, Number = 33, QuotedIdent = 34, QuotedString = 35, At = 36, Bang = 37, Colon = 38, ColonColon = 39, Comma = 40, Dot = 41, DotDot = 42, Equal = 43, LAngle = 44, LBrace = 45, LBracket = 46, LParen = 47, Minus = 48, Plus = 49, RAngle = 50, RArrow = 51, RBrace = 52, RBracket = 53, RParen = 54, Semicolon = 55, Slash = 56, SlashSlash = 57, Star = 58,
}
The full set of rowan node and token kinds used by the MASM CST.

Variants



Tombstone = 0



Error = 1



SourceFile = 2



Doc = 3



Namespace = 4



ExternPackage = 5



Submodule = 6



Import = 7



ImportList = 8



ImportSpecifier = 9



Constant = 10



TypeDecl = 11



AdviceMap = 12



BeginBlock = 13



Procedure = 14



Attribute = 15



Visibility = 16



Signature = 17



Block = 18



IfOp = 19



WhileOp = 20



DoWhileOp = 21



RepeatOp = 22



Instruction = 23



Path = 24



Expr = 25



TypeBody = 26



Whitespace = 27



Newline = 28



Comment = 29



DocComment = 30



Ident = 31



SpecialIdent = 32



Number = 33



QuotedIdent = 34



QuotedString = 35



At = 36



Bang = 37



Colon = 38



ColonColon = 39



Comma = 40



Dot = 41



DotDot = 42



Equal = 43



LAngle = 44



LBrace = 45



LBracket = 46



LParen = 47



Minus = 48



Plus = 49



RAngle = 50



RArrow = 51



RBrace = 52



RBracket = 53



RParen = 54



Semicolon = 55



Slash = 56



SlashSlash = 57



Star = 58

Implementations

Source

impl SyntaxKind

pub fn is_trivia(self) -> bool

Returns true if this kind represents trivia that the formatter may preserve but most typed accessors ignore.